==> kdetoys-3.0.1.tar.bz2: kdetoys-3.0.1/kweather/prefsDialog.h <==
/**********************************************************************

	--- Qt Architect generated file ---

	File: prefsDialog.h
	Last generated: Thu Jul 6 17:58:38 2000

 *********************************************************************/

#ifndef prefsDialog_included
#define prefsDialog_included

#include <kurllabel.h>
#include <qcheckbox.h>
#include <qlcdnumber.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qslider.h>
#include <qspinbox.h>
#include <qtoolbutton.h>
#include <qfont.h>
#include "prefdialogview.h"

class prefsDialog : public prefsDialogData
{
    Q_OBJECT

public:

    prefsDialog(
        QWidget *parent = 0,const char *name = "name" );

    virtual ~prefsDialog();
    /** Get the report location string. */
    QString getReportLocation();
    QString getGMTOffset();
    int getTimeValue();
    bool getMetricMode();
    bool getOffLineMode();
    bool getSmallView();
    bool getLoggingEnabled();
    void setLoggingEnabled(bool);
    QString getFileName();
    /** Set the pref box file name to the current prefs file name. */
    void setFileName( QString s );
    /** Set the small view mode checkbox */
    void setSmallView( bool b);
    /** Set the metric mode check box */
    void setMetricMode( bool b );
    /** Set the LCD and Slider value */
    void setTimeValue(int i);
    /** Set the GMT offset */
    void setGMTOffset(int i);
    /** Set the offline mode checkbox */
    void setOffLineMode( bool b );
    /** The current report location */
    void setLocation( QString s );

    QFont getFont();
    void setFont(QFont theFont);

public slots: // Public slots
   /** Handle file selection */
    void selectFile();
    /** Open KFM to this link. */
    void processURL(const QString&);
    /** Make new fonts **/
    void font();
    // Enable/disable logfile input
    void enableLogFile(bool b);

private:
    QFont theFont;
};
#endif // prefsDialog_included

==> kdetoys-3.1.tar.bz2: kdetoys-3.1/kweather/prefsDialog.h <==
/**********************************************************************

	--- Qt Architect generated file ---

	File: prefsDialog.h
	Last generated: Thu Jul 6 17:58:38 2000

 *********************************************************************/

#ifndef prefsDialog_included
#define prefsDialog_included

#include <kurllabel.h>
#include <qcheckbox.h>
#include <qlcdnumber.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qslider.h>
#include <qspinbox.h>
#include <qtoolbutton.h>
#include <qfont.h>
#include "prefdialogview.h"

class prefsDialog : public prefsDialogData
{
    Q_OBJECT

public:

    prefsDialog(QWidget *parent = 0,const char *name = "name" );

    virtual ~prefsDialog();
    /** Get the report location string. */
    QString reportLocation() const;
    QFont font() const;
    int updateInterval() const;
    bool offLineMode() const;
    bool smallView() const;
    bool enableLog() const;
    QString logFile() const;
    /** Set the pref box file name to the current prefs file name. */
    void setLogFile( QString s );
    /** Set the small view mode checkbox */
    void setSmallView( bool b);
    /** Set the LCD and Slider value */
    void setUpdateInterval(int i);
    /** Set the offline mode checkbox */
    void setOffLineMode( bool b );
    /** The current report location */
    void setReportLocation( QString s );
    void setEnableLog(bool);
    void setFont(QFont theFont);

private slots:
    /** Open KFM to this link. */
    void processURL(const QString&);
    /** Make new fonts **/
    void selectFont();
    // Enable/disable logfile input
    void enableLogWidgets(bool b);
   /** Offline mode was toggled **/
   void offlineModeToggled(bool);

private:
    QFont theFont;
    void updateFont();
};
#endif // prefsDialog_included
